compile_model() compiles the information of model class object x into 3
main tables:
date_tab Table for estimated break date in the model
with 90% and 95% confidence intervals based on robust,hetomega, hetq options
for errors
and prewhit option
RS_tab Table for estimated coefficients for z regressors
with corrected standard errors based on robust,hetdat,hetvar
options for errors and prewhit option
FS_tab Table for estimated coefficients for x regressors
with corrected standard errors based on robust,hetdat,hetvar options for errors and prewhit option
compile_model(x, digits = 3)x The input list of model class contains the following tables:
date_tab A data frame storing the break date estimated by the model,
and their corresponding confidence intervals
RS_tab A data frame storing the estimated coefficients which allowed to
change across regimes with corrected standard errors
FS_tab A data frame storing the estimated coefficients which is constant
across regimes with corrected standard errors
the model class to format
number of digits displayed in console. Default value is 3