compile_sbtests formats the output of the sbtests into 2 tables
supF1 table containing Sup F tests of 0 versus 1 to m breaks
with critical values of the corresponding tests
compile_sbtests(x, digits = 3)class sbtests x with appended 2 data frames:
supF1 A data frame contains SupF tests statistics of 0 versus m breaks, where
m is maximum number of breaks considered in x with critical values at
{10%,5%,2.5%,1%} level
UDMax A data frame contains Double Max test statistics with with critical values at
{10%,5%,2.5%,1%} level
sbtests class object
number of decimal places displayed