compile_seqtests formats the output of the seqtests class object to 1 table
sfl table containing sequential sup F tests statistics
of l versus l+1 for l in 1 to m breaks
with critical values of the corresponding tests at
{1%, 2.5%, 5%, 10%} significance levels
compile_seqtests(x)class seqtests list x with appended data frame sfl containing the
sequential SupF test statistics with critical values at
{10%,5%,2.5%,1%} level
seqtests class object